@@ -1,4 +1,9 @@
-/* CatalystX::CRUD::YUI custom JavaScript */
+/* CatalystX::CRUD::YUI custom JavaScript 
+
+# sync with .pm files
+my $VERSION = '0.011';   
+
+*/
 YAHOO.namespace('crud');
 // global var trackers
 YAHOO.crud.TABS         = [];
@@ -311,9 +316,9 @@ YAHOO.crud.load_livegrid_by_id = function(id) {
 }
 
 YAHOO.crud.livegrid_form = function(args) {
-    Logger(args);
+    //Logger(args);
     var tab = YAHOO.crud.TABS[args.index];
-    Logger(tab);
+    //Logger(tab);
     var formId = 'livegrid' + args.index + '-form';
 
     // fetch the html and insert it
@@ -599,7 +604,7 @@ YAHOO.crud.new_livegrid = function(index) {
             * but any bigger than 50 caused "glitches" in my testing.
             * TODO >50 is problem likely due to how cxc detects limit
             */
-            bufferSize : 50,   // cxc does 200 max by default
+            bufferSize : 200,   // cxc does 200 max by default
             reader     : bufferedReader,
             sortInfo   : {field: opts.sort_by, direction: opts.sort_dir },
             url        : opts.url
@@ -614,7 +619,7 @@ YAHOO.crud.new_livegrid = function(index) {
          * a value of 100 for a bufferSize of 300).
          */
         this.view = new Ext.ux.grid.livegrid.GridView({
-            nearLimit : 15,
+            nearLimit : 50,
             loadMask : {
                 msg : 'Please wait...'
             }
@@ -704,6 +709,7 @@ YAHOO.crud.new_livegrid = function(index) {
 
     tab.grid.panel = new tab.grid.cls(gridopts);
     tab.grid.panel.getSelectionModel().on('rowselect', opts.clickhandler);
+    tab.grid.panel.getSelectionModel().on('rowdeselect', opts.clickhandler);
     tab.grid.panel.render();
 
     //Logger("rendered grid " + tab.name);
@@ -735,6 +741,8 @@ YAHOO.crud.add_livegrid_row = function(opts) {
     
     // already created. just show it.
     if (chooser) {
+        //Logger("chooser already exists");
+        chooser.getSelectionModel().clearSelections();
         chooser.show();
         chooser.store.reload();
         return;
@@ -770,6 +778,7 @@ YAHOO.crud.handle_chooser_m2m = function(args) {
             },
             failure: function(o) {
                 YAHOO.crud.handleXHRFailure(o);
+                tab.chooser.panel.getSelectionModel().clearSelections();
             }
         },
         'x-tunneled-method=PUT'
@@ -860,7 +869,7 @@ YAHOO.crud.new_livegrid_chooser = function(index) {
             * but any bigger than 50 caused "glitches" in my testing.
             * TODO >50 is problem likely due to how cxc detects limit
             */
-            bufferSize : 50,   // cxc does 200 max by default
+            bufferSize : 200,   // cxc does 200 max by default
             reader     : bufferedReader,
             sortInfo   : {field: tab.grid.opts.sort_by, direction: tab.grid.opts.sort_dir },
             url        : tab.grid.opts.foreign.chooser_url
@@ -875,7 +884,7 @@ YAHOO.crud.new_livegrid_chooser = function(index) {
          * a value of 100 for a bufferSize of 300).
          */
         this.view = new Ext.ux.grid.livegrid.GridView({
-            nearLimit : 15,
+            nearLimit : 50,
             loadMask : {
                 msg : 'Please wait...'
             }
@@ -956,6 +965,11 @@ YAHOO.crud.rm_livegrid_rows = function(args) {
     var sm   = grid.getSelectionModel();
     var rows = sm.getSelections();
     
+    if (!rows.length) {
+        alert("No rows are selected.");
+        return;
+    }
+    
     if (confirm('Are you sure?')) {
        // make ajax calls to break relationships
        
@@ -991,27 +1005,28 @@ YAHOO.crud.handle_related_livegrid_click = function(args) {
         Logger('no row passed on click');
         return;
     }
+    
+    //Logger(args);
         
     if (args.sm.checkBoxClicked == true) {
         return;
     }
     else {
-        var tab = YAHOO.crud.TABS[args.index];
+        //var tab = YAHOO.crud.TABS[args.index];
         //Logger(tab);
         //Logger(args);
-        var uri;
-        if (args.m2m_url != '/') {
-            uri = args.m2m_url + args.rec.id + '/' + args.action;
-        }
-        else {
-            uri = args.url + args.rec.id + '/' + args.action;
-        }
-        
-        //Logger(uri);
-        //return;
         
+        var uri = args.url + args.rec.id + '/' + args.action;
         if (args.action == 'livegrid_edit_form') {
-            YAHOO.crud.livegrid_form({'index':args.index, 'form':uri});
+        
+            // if de-selecting the row, erase the form
+            if (!args.sm.isSelected(args.rec)) {
+                var formId = 'livegrid' + args.index + '-form';
+                YAHOO.util.Dom.get(formId).innerHTML = '';
+                return;
+            }
+        
+            YAHOO.crud.livegrid_form({'index':args.index,'form':uri});
         }
         else {
             window.location = uri;
